@@ -33,7 +33,6 @@
 
 #include "libegg/egg-datetime.h"
 
-#include "libseahorse/seahorse-passphrase.h"
 #include "libseahorse/seahorse-progress.h"
 #include "libseahorse/seahorse-util.h"
 #include "libseahorse/seahorse-widget.h"
@@ -177,7 +176,7 @@ on_generate_key_complete (GObject *source,
 	GError *error = NULL;
 
 	if (!seahorse_gpgme_key_op_generate_finish (SEAHORSE_GPGME_KEYRING (source), result, &error))
-		seahorse_util_handle_error (&error, NULL, _("Couldn't generate PGP key"));
+		seahorse_util_handle_error (&error, NULL, _("Couldn’t generate PGP key"));
 }
 
 /**
@@ -207,15 +206,15 @@ seahorse_gpgme_generate_key (SeahorseGpgmeKeyring *keyring,
 {
 	GCancellable *cancellable;
 	const gchar *pass;
-	GtkDialog *dialog;
+	SeahorsePassphrasePrompt *dialog;
 	const gchar *notice;
 
-	dialog = seahorse_passphrase_prompt_show (_("Passphrase for New PGP Key"),
+	dialog = seahorse_passphrase_prompt_show_dialog (_("Passphrase for New PGP Key"),
 	                                          _("Enter the passphrase for your new key twice."),
 	                                          NULL, NULL, TRUE);
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
-	if (gtk_dialog_run (dialog) == GTK_RESPONSE_ACCEPT) {
-		pass = seahorse_passphrase_prompt_get (dialog);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		pass = seahorse_passphrase_prompt_get_text (dialog);
 		cancellable = g_cancellable_new ();
 		seahorse_gpgme_key_op_generate_async (keyring, name, email, comment,
 		                                      pass, type, bits, expires,
@@ -224,7 +223,7 @@ seahorse_gpgme_generate_key (SeahorseGpgmeKeyring *keyring,
 
 		/* Has line breaks because GtkLabel is completely broken WRT wrapping */
 		notice = _("When creating a key we need to generate a lot of\n"
-		           "random data and we need you to help. It's a good\n"
+		           "random data and we need you to help. It’s a good\n"
 		           "idea to perform some other action like typing on\n"
 		           "the keyboard, moving the mouse, using applications.\n"
 		           "This gives the system the random data that it needs.");
@@ -348,16 +347,28 @@ on_gpgme_generate_entry_changed (GtkEditable *editable,
     SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
     GtkWidget *widget;
     gchar *name;
+    gboolean name_long_enough;
 
     /* A 5 character name is required */
     widget = seahorse_widget_get_widget (swidget, "name-entry");
     g_return_if_fail (widget != NULL);
     name = g_strdup (gtk_entry_get_text (GTK_ENTRY (widget)));
-    
+    name_long_enough = name && strlen (g_strstrip (name)) >= 5;
+
+    /* If not, show the user and disable the create button */
+    if (!name_long_enough) {
+        g_object_set (widget,
+            "secondary-icon-name", "dialog-warning-symbolic",
+            "secondary-icon-tooltip-text", _("Name must be at least 5 characters long."),
+            NULL);
+    } else {
+        g_object_set (widget, "secondary-icon-name", NULL, NULL);
+    }
+
     widget = seahorse_widget_get_widget (swidget, "ok");
     g_return_if_fail (widget != NULL);
     
-    gtk_widget_set_sensitive (widget, name && strlen (g_strstrip (name)) >= 5);
+    gtk_widget_set_sensitive (widget, name_long_enough);
     g_free (name);
 }
 
