@@ -27,7 +27,6 @@
 #include "seahorse-gpgme-keyring.h"
 #include "seahorse-keyserver-search.h"
 
-#include "libseahorse/seahorse-key-manager-store.h"
 #include "libseahorse/seahorse-progress.h"
 #include "libseahorse/seahorse-util.h"
 
@@ -151,7 +150,7 @@ on_remote_find (GtkAction* action, SeahorseKeyserverResults* self)
 {
 	g_return_if_fail (SEAHORSE_IS_KEYSERVER_RESULTS (self));
 	g_return_if_fail (GTK_IS_ACTION (action));
-	seahorse_keyserver_search_show (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)));
+	seahorse_keyserver_search_show (GTK_WINDOW (self));
 }
 
 static void
@@ -164,8 +163,8 @@ on_import_complete (GObject *source,
 
 	if (!seahorse_pgp_backend_transfer_finish (SEAHORSE_PGP_BACKEND (source),
 	                                           result, &error))
-		seahorse_util_handle_error (&error, seahorse_catalog_get_window (self),
-		                            _("Couldn't import keys"));
+		seahorse_util_handle_error (&error, GTK_WINDOW (self),
+		                            _("Couldn’t import keys"));
 
 	g_object_unref (self);
 }
@@ -240,7 +239,7 @@ static const GtkActionEntry GENERAL_ENTRIES[] = {
 };
 
 static const GtkActionEntry SERVER_ENTRIES[] = {
-	{ "remote-find", GTK_STOCK_FIND, N_("_Find Remote Keys..."), "",
+	{ "remote-find", GTK_STOCK_FIND, N_("_Find Remote Keys…"), "",
 	  N_("Search for keys on a key server"), G_CALLBACK (on_remote_find) }
 };
 
@@ -279,10 +278,10 @@ seahorse_keyserver_results_constructed (GObject *obj)
 	if (g_utf8_strlen (self->pv->search_string, -1) == 0) {
 		title = g_strdup (_("Remote Keys"));
 	} else {
-		title = g_strdup_printf (_ ("Remote Keys Containing '%s'"), self->pv->search_string);
+		title = g_strdup_printf (_ ("Remote Keys Containing “%s”"), self->pv->search_string);
 	}
 
-	window = seahorse_catalog_get_window (SEAHORSE_CATALOG (self));
+	window = GTK_WINDOW (self);
 	gtk_window_set_default_geometry(window, 640, 476);
 	gtk_widget_set_events (GTK_WIDGET (window), GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 	gtk_window_set_title (window, title);
@@ -475,13 +474,11 @@ on_search_completed (GObject *source,
 {
 	SeahorseKeyserverResults *self = SEAHORSE_KEYSERVER_RESULTS (user_data);
 	GError *error = NULL;
-	GtkWindow *window;
 
 	seahorse_pgp_backend_search_remote_finish (NULL, result, &error);
 	if (error != NULL) {
-		window = seahorse_catalog_get_window (SEAHORSE_CATALOG (self));
 		g_dbus_error_strip_remote_error (error);
-		seahorse_util_show_error (GTK_WIDGET (window),
+		seahorse_util_show_error (GTK_WIDGET (self),
 		                          _("The search for keys failed."), error->message);
 		g_error_free (error);
 	}
@@ -490,14 +487,14 @@ on_search_completed (GObject *source,
 }
 /**
  * seahorse_keyserver_results_show:
- * @parent: A GTK window as parent (or NULL)
  * @search_text: The test to search for
+ * @parent: A GTK window as parent (or NULL)
  *
  * Creates a search results window and adds the operation to it's progress status.
  *
  */
 void
-seahorse_keyserver_results_show (const char* search_text)
+seahorse_keyserver_results_show (const char* search_text, GtkWindow *parent)
 {
 	SeahorseKeyserverResults* self;
 	GCancellable *cancellable;
@@ -508,6 +505,7 @@ seahorse_keyserver_results_show (const char* search_text)
 	self = g_object_new (SEAHORSE_TYPE_KEYSERVER_RESULTS,
 	                     "ui-name", "keyserver-results",
 	                     "search", search_text,
+			     "transient-for", parent,
 	                     NULL);
 
 	/* Destorys itself with destroy */
