@@ -39,7 +39,6 @@
 #include "seahorse-common.h"
 
 #include "libseahorse/seahorse-bind.h"
-#include "libseahorse/seahorse-object.h"
 #include "libseahorse/seahorse-object-model.h"
 #include "libseahorse/seahorse-object-widget.h"
 #include "libseahorse/seahorse-util.h"
@@ -314,7 +313,7 @@ on_pgp_names_primary_clicked (GtkWidget *widget,
 		g_return_if_fail (SEAHORSE_IS_GPGME_UID (uid));
 		err = seahorse_gpgme_key_op_primary_uid (SEAHORSE_GPGME_UID (uid));
 		if (!GPG_IS_OK (err)) 
-			seahorse_gpgme_handle_error (err, _("Couldn't change primary user ID"));
+			seahorse_gpgme_handle_error (err, _("Couldn’t change primary user ID"));
 	}
 }
 
@@ -333,7 +332,7 @@ on_pgp_names_delete_clicked (GtkWidget *widget,
 		return;
 	
 	g_return_if_fail (SEAHORSE_IS_GPGME_UID (uid));
-	message = g_strdup_printf (_("Are you sure you want to permanently delete the '%s' user ID?"), 
+	message = g_strdup_printf (_("Are you sure you want to permanently delete the “%s” user ID?"), 
 	                           seahorse_object_get_label (SEAHORSE_OBJECT (uid)));
 	ret = seahorse_delete_dialog_prompt (GTK_WINDOW (seahorse_widget_get_toplevel (swidget)), message);
 	g_free (message);
@@ -343,7 +342,7 @@ on_pgp_names_delete_clicked (GtkWidget *widget,
 	
 	gerr = seahorse_gpgme_key_op_del_uid (SEAHORSE_GPGME_UID (uid));
 	if (!GPG_IS_OK (gerr))
-		seahorse_gpgme_handle_error (gerr, _("Couldn't delete user ID"));
+		seahorse_gpgme_handle_error (gerr, _("Couldn’t delete user ID"));
 }
 
 G_MODULE_EXPORT void
@@ -414,10 +413,10 @@ names_update_row (SeahorseObjectModel *skmodel, SeahorseObject *object,
 	name = seahorse_object_get_markup (object);
 	id = seahorse_object_get_identifier (object);
 
-	/* TRANSLATORS: [Unknown] signature name */
 	gtk_tree_store_set (GTK_TREE_STORE (skmodel), iter,
 	                    UIDSIG_OBJECT, NULL,
 	                    UIDSIG_ICON, icon,
+	                    /* TRANSLATORS: [Unknown] signature name */
 	                    UIDSIG_NAME, name ? name : _("[Unknown]"),
 	                    UIDSIG_KEYID, id, -1);
 	g_object_unref (icon);
@@ -523,10 +522,10 @@ do_names (SeahorseWidget *swidget)
                                                      -1, "", renderer,
                                                      "gicon", UIDSIG_ICON, NULL);
 
-        /* TRANSLATORS: The name and email set on the PGP key */
         renderer = gtk_cell_renderer_text_new ();
         g_object_set (renderer, "yalign", 0.0, "xalign", 0.0, NULL);
         gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget), 
+                                                     /* TRANSLATORS: The name and email set on the PGP key */
                                                      -1, _("Name/Email"), renderer,
                                                      "markup", UIDSIG_NAME, NULL);
 
@@ -667,7 +666,7 @@ on_pgp_owner_photo_primary_button (GtkWidget *widget,
         
 	gerr = seahorse_gpgme_key_op_photo_primary (photo);
 	if (!GPG_IS_OK (gerr))
-		seahorse_gpgme_handle_error (gerr, _("Couldn't change primary photo"));
+		seahorse_gpgme_handle_error (gerr, _("Couldn’t change primary photo"));
 }
 
 static void
@@ -1091,7 +1090,7 @@ on_pgp_details_del_subkey_button (GtkButton *button,
 	
 	err = seahorse_gpgme_key_op_del_subkey (SEAHORSE_GPGME_SUBKEY (subkey));
 	if (!GPG_IS_OK (err))
-		seahorse_gpgme_handle_error (err, _("Couldn't delete subkey"));
+		seahorse_gpgme_handle_error (err, _("Couldn’t delete subkey"));
 }
 
 G_MODULE_EXPORT void
@@ -1145,7 +1144,7 @@ on_export_complete (GObject *source,
 
 	seahorse_exporter_export_to_file_finish (SEAHORSE_EXPORTER (source), result, &error);
 	if (error != NULL)
-		seahorse_util_handle_error (&error, parent, _("Couldn't export key"));
+		seahorse_util_handle_error (&error, parent, _("Couldn’t export key"));
 
 	g_object_unref (parent);
 }
@@ -1570,9 +1569,9 @@ trust_update_row (SeahorseObjectModel *skmodel, SeahorseObject *object,
 	name = seahorse_object_get_label (object);
 	id = seahorse_object_get_identifier (object);
 
-	/* TRANSLATORS: [Unknown] signature name */
 	gtk_tree_store_set (GTK_TREE_STORE (skmodel), iter,
 	                    SIGN_ICON, icon,
+	                    /* TRANSLATORS: [Unknown] signature name */
 	                    SIGN_NAME, name ? name : _("[Unknown]"),
 	                    SIGN_KEYID, id,
 	                    SIGN_TRUSTED, trusted,
@@ -1854,8 +1853,8 @@ do_trust (SeahorseWidget *swidget)
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
 			                                             -1, "", renderer,
 			                                             "gicon", SIGN_ICON, NULL);
-			/* TRANSLATORS: The name and email set on the PGP key */
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget), 
+			                                             /* TRANSLATORS: The name and email set on the PGP key */
 			                                             -1, _("Name/Email"), gtk_cell_renderer_text_new (), 
 			                                             "text", SIGN_NAME, NULL);
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget), 
@@ -1983,7 +1982,7 @@ seahorse_pgp_key_properties_show (SeahorsePgpKey *pkey, GtkWindow *parent)
 		swidget = setup_private_properties (pkey, parent);
 	if (swidget) {
 		seahorse_widget_show (swidget);
-		return g_object_ref (seahorse_widget_get_toplevel (swidget));
+		return GTK_WINDOW (g_object_ref (seahorse_widget_get_toplevel (swidget)));
 	}
 
 	return NULL;
